==> nextcloud-app-calendar-1%3A2.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/af.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s het die kalender »%s« gepubliseer",
    "Hello," : "Dag,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ons wil u graag inlig dat %s die kalender »%s« gepubliseer het.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Geluk!",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "'n Kalendertoep vir Nextcloud",
    "Today" : "Vandag",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "List" : "Lys",
    "Download" : "Laai af",
    "Delete" : "Skrap",
    "Share link" : "Deel skakel",
    "Share with users or groups" : "Deel met gebruikers of groepe",
    "No users or groups" : "Geen gebruikers of groepe",
    "can edit" : "kan wysig",
    "New calendar" : "Nuwe kalender",
    "Filename" : "Lêernaam",
    "Cancel" : "Kanselleer",
    "Automatic" : "Outomaties",
    "Actions" : "Aksies",
    "Show week numbers" : "Toon weeknommers",
    "Notification" : "Kennisgewing",
    "Email" : "E-pos",
    "Unknown" : "Onbekend",
    "All day" : "Heeldag",
    "never" : "nooit",
    "after" : "na",
    "Repeat" : "Herhaal",
    "Monday" : "Maandag",
    "Summary" : "Opsomming",
    "More" : "Nog",
    "Save" : "Stoor",
    "Update" : "Werk by",
    "Personal" : "Persoonlik",
    "Details" : "Details",
    "Attendees" : "Bywoners",
    "Reminders" : "Herinneringe",
    "Close" : "Sluit",
    "Anniversary" : "Herdenking",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Daily" : "Daagliks",
    "Weekly" : "Weekliks",
    "Location" : "Ligging",
    "Description" : "Beskrywing",
    "Confirmed" : "Bevestig",
    "Tentative" : "Tentatief",
    "Categories" : "Kategorieë",
    "Mail" : "Pos",
    "Global" : "Globaal"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/af.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s het die kalender »%s« gepubliseer",
    "Hello," : "Dag,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ons wil u graag inlig dat %s die kalender »%s« gepubliseer het.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Geluk!",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "'n Kalendertoep vir Nextcloud",
    "Today" : "Vandag",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "List" : "Lys",
    "Download" : "Laai af",
    "Delete" : "Skrap",
    "Share link" : "Deel skakel",
    "Share with users or groups" : "Deel met gebruikers of groepe",
    "No users or groups" : "Geen gebruikers of groepe",
    "can edit" : "kan wysig",
    "New calendar" : "Nuwe kalender",
    "Filename" : "Lêernaam",
    "Cancel" : "Kanselleer",
    "Automatic" : "Outomaties",
    "Actions" : "Aksies",
    "Show week numbers" : "Toon weeknommers",
    "Notification" : "Kennisgewing",
    "Email" : "E-pos",
    "Unknown" : "Onbekend",
    "All day" : "Heeldag",
    "Repeat" : "Herhaal",
    "Save" : "Stoor",
    "never" : "nooit",
    "after" : "na",
    "Monday" : "Maandag",
    "More" : "Nog",
    "Update" : "Werk by",
    "Global" : "Globaal",
    "Personal" : "Persoonlik",
    "Details" : "Details",
    "Attendees" : "Bywoners",
    "Close" : "Sluit",
    "Anniversary" : "Herdenking",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Daily" : "Daagliks",
    "Weekly" : "Weekliks",
    "Location" : "Ligging",
    "Description" : "Beskrywing",
    "Confirmed" : "Bevestig",
    "Tentative" : "Tentatief",
    "Categories" : "Kategorieë",
    "Mail" : "Pos"
},
"nplurals=2; plural=(n != 1);");
